@@ -4,8 +4,9 @@ utils::globalVariables(
       "key", "..indicator", "bad_class", ".key", ".index", ".pred", ".value",
       ".conf_hi", ".conf_lo", ".fitted", ".type", "actual", "prediction",
       ".estimate", ".estimator", ".metric", ".model", ".nested.col",
-      "value", ".model_desc", ".model_id",
+      "value", ".model_desc", ".model_id", "shapiro_wilk", "durbin_watson",
       ".actual", ".calibration_data", ".prediction", ".ci",
       "yhat", ".model_desc_new", ".model_desc_old", ".model_desc_user",
-      ".model_table", ".model_table_clean", ".residuals", ".is_null", ".")
+      ".model_table", ".model_table_clean", ".residuals", ".is_null", ".",
+      ".final_values", ".idx_values", ".pred_values", ".row_id")
 )
